@@ -4,6 +4,7 @@ from strange_case.configurators import *
 CONFIG = ConfigDict({
     ##|  ROOT URL
     'root_url': '/',
+    'config_file': 'config.yaml',
 
     ##|  USED TO CLEAN DEPLOY PATH
     'remove_stale_files': True,
@@ -23,7 +24,6 @@ CONFIG = ConfigDict({
     # these are ensured to be loaded first
     '__configurators_pre__': [
         'strange_case.configurators.meta_before',
-        'strange_case.configurators.dont_inherit',
         'strange_case.configurators.file_types',
         'strange_case.configurators.merge_files_config',
         'strange_case.configurators.folder_config_file',
@@ -46,4 +46,15 @@ CONFIG = ConfigDict({
         'strange_case.configurators.set_url',
         'strange_case.configurators.meta_after',
     ],
+    'dont_inherit': [
+        'type',
+        'name',
+        'target_name',
+        'title',
+        'created_at',
+        'order',
+        'iterable',
+        'url',
+        'skip',
+    ]
 })
